version 8.2
clear
set matsize 180
set logtype text
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture log close
log using "brazrloc/logs/niv100-agg.log", replace


// RAIS information at CNAE, mapped to Nivel 100
//----------------------------------------------

insheet using "rais/base-agg/cnae/aggsec.csv", comma clear names
rename clas_cnae_95 cnae
rename ano year
sort cnae year
label var cnae "Sector (CNAE)"
label var year "Calendar year"
label var rem_dezembro "December wage per worker"
label var temp_empr "Tenure at plant per worker"
label var indchild "Share: Workers age 10 to 14"
label var indyouth "Share: Workers age 15 to 17"
label var indadol  "Share: Workers age 18 to 24"
label var indnasc  "Share: Workers age 25 to 29"
label var indearly "Share: Workers age 30 to 39"
label var indpeak  "Share: Workers age 40 to 49"
label var indlate  "Share: Workers age 50 to 64"
label var indretir "Share: Workers age 65 or older"
label var indprim     "Share: Prim. or middle schl. ed."
label var indhigh     "Share: High school education"
label var indprim_alt "Share: Primary school education"
label var indhigh_alt "Share: Middle or high schl. ed."
label var indscoll    "Share: Some college education"
label var indgrad     "Share: Complete college educ."
label var indfem "Share: Female workers"
label var indprjob "Share: Private-sector contracts"
label var indprof   "Share: Profess. or manag'l. occ."
label var indtech   "Share: Techn. or supervis. occ."
label var indwhit   "Share: Other white-collar occ."
label var indsklb   "Share: Skilled blue-collar occ."
label var indunsklb "Share: Unskilled blue-coll. occ."
label var indprown_pis "Share: Jobs at private firms"
label var n_pis "Number of Workers"
label var indprown_identificad "Share: Plants of private firms"
label var n_identificad "Number of Plants"
label var indprown_cnpj_radic "Share: Private firms"
label var n_cnpj_radic "Number of Firms"
label var mod_subs_ibge "IBGE sector (median firm mode)"
label var min_mod_subs_ibge "Minimum mode of IBGE sector"
label var max_mod_subs_ibge "Maximum mode of IBGE sector"
label var sum_rem_dezembro "December wage bill (sector)"
keep cnae year indprown_pis n_pis n_identificad n_cnpj_radic
drop if cnae<1000  // remove missing sectors
replace cnae = int(cnae/10)  // remove control digit
sort cnae year
merge cnae using "brazcomp/filters/cnae2niv100"
tab _m
qui count if _m==2 | (_m==1 & cnae>=1000 & cnae<=3999)
if `r(N)'>0  STOP
drop _m
sort cnae year
merge cnae using "brazcomp/filters/cnae2niv100-app-agric", update
tab _m
qui count if (_m==1 & cnae<=999)  // note: CNAE 170 not in RAIS data
if `r(N)'>0  STOP
drop if niv100==. | _m==2  // drop CNAE 170 (not in RAIS data)
drop _m

preserve
tempfile rais100
  order niv100 year
  collapse (sum) n_pis n_identificad n_cnpj_radic (mean) indprown_pis [w=n_pis], by(niv100 year)
  label var indprown_pis "Share: Jobs at private firms"
  label var n_pis "Number of Workers"
  label var n_identificad "Number of Plants"
  label var n_cnpj_radic "Number of Firms"
  sort niv100 year
  compress
  save `rais100'
restore, preserve
tempfile rais50
  gen byte niv50 = int(niv100/100)
  label var niv50 "Sector (Nivel 50)"
  order niv50 year
  collapse (sum) n_pis n_identificad n_cnpj_radic (mean) indprown_pis [w=n_pis], by(niv50 year)
  label var indprown_pis "Share: Jobs at private firms"
  label var n_pis "Number of Workers"
  label var n_identificad "Number of Plants"
  label var n_cnpj_radic "Number of Firms"
  sort niv50 year
  compress
  save `rais50'
restore


// PIA Ratios at Nivel 100
//------------------------
// code similar to brazempl/%2/repl-pia-data.do [left out: RAIS variables, added in: intmed/empl]

use firm year niv100 labfbl labfwh apimmo1x lnvaladd sales lnintmed profit using "brazaux/Xpia/firms-86-98", clear  // (from brazprod/%stata/%1prepare-pia/)

* produce valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl [implicitly weighted by denominator (empl, sales)]
gen empl = (labfbl + labfwh)
label var empl "Employment (PIA)"
gen cap = (apimmo1x)
label var cap "Capital (PIA)"
gen valadd = exp(lnvaladd)
label var valadd "Value added"
gen intmed = exp(lnintmed)
label var cap "Intm. Inputs"

preserve
tempfile ratio100
  collapse (mean) valadd sales cap intmed empl profit labfwh, by(niv100 year) fast
  foreach ratio in valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl {
    local numer = substr("`ratio'",1,index("`ratio'","_")-1)
    local denom = substr("`ratio'",index("`ratio'","_")+1,length("`ratio'"))
    gen `numer'_`denom' = (`numer')/(`denom')
    }
  keep niv100 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl
  label var niv100 "Sector (Nivel 100)"
  label var empl "Employement (PIA)"
  label var cap "Capital (PIA)"
  label var valadd_empl "Value Added / Labor Force"
  label var sales_empl "Sales / Labor Force"
  label var cap_empl "Capital / Labor Force"
  label var intmed_empl "Intm. Inp. / Labor Force"
  label var profit_sales "Operating Income / Sales"
  label var labfwh_empl "Share White Collar Workers"
  order niv100 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl
  sort niv100 year
  compress
  save `ratio100'
restore, preserve
tempfile ratio50
  gen byte niv50 = int(niv100/100)
  label var niv50 "Sector (Nivel 50)"
  collapse (mean) valadd sales cap intmed empl profit labfwh, by(niv50 year) fast
  foreach ratio in valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl {
    local numer = substr("`ratio'",1,index("`ratio'","_")-1)
    local denom = substr("`ratio'",index("`ratio'","_")+1,length("`ratio'"))
    gen `numer'_`denom' = (`numer')/(`denom')
    }
  keep niv50 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl
  label var niv50 "Sector (Nivel 50)"
  label var empl "Employement (PIA)"
  label var cap "Capital (PIA)"
  label var valadd_empl "Value Added / Labor Force"
  label var sales_empl "Sales / Labor Force"
  label var cap_empl "Capital / Labor Force"
  label var intmed_empl "Intm. Inp. / Labor Force"
  label var profit_sales "Operating Income / Sales"
  label var labfwh_empl "Share White Collar Workers"
  order niv50 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl
  sort niv50 year
  compress
  save `ratio50'
restore

// PIA Productivity measures at Nivel 50
//--------------------------------------

use firm year niv100 lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed kappa1 mu labfbl labfwh using "brazaux/Xpia/firms-86-98", clear  // (from brazprod/%stata/%1prepare-pia/)
gen byte niv50 = int(niv100/100)
drop niv100

* settings for productivity estimates (as in brazprod/%stata/%4tfp/prodlevel.do)
local esttype "op" /* "op" : Olley-Pakes */
local choice 3 /* Choice 3: FGV-IPA (and general) Deflators 86-98 */
if `choice'==3  local ext "ipa"
local fdfl 2 /* Choice 2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
global out 2 /* Choice 2: "output" */
if $out==2  local outtype "output"
global trd 0 /* Choice 0: trend variables and year dummies OFF */
if $trd==0  local trdtype "notrend"
global fe 1 /* Choice 1: fixed effects in OP estimation ON  */
if $fe  local fetype "fe"
global iniols 2 /* Choice 2: Set initial values to FE estimates and terms from linear regression */
global polynl 3 /* Choice 3: Polynomial of 3rd order is used in Step 3 */
local polynl=$polynl
global xeff 1 /* Choice 1: Approximate for X-efficiency choice by managers */
if $xeff  local xeff="x"

* derive productivity figures at Nivel 50
sort niv50
merge niv50 using "brazaux/pia/prodcoeff-brazprod", nokeep
tab _m
qui count if _m~=3
if `r(N)' > 0  STOP
if "`esttype'" == "op" {
  if $fe~=2 {
   if $out==2 {
    if $trd==3  gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril
    else        gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed
    }
  }
}
label var lntfp "Log TFP"
if "`esttype'" == "op" {
    if $out==2  gen double lnlp=lntfp + betak*lnapk1 + betaq*lnapq1 - (1-betabl-betawh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + betaintm*lnintmed
  }
label var lnlp "Log LP"
if "`esttype'" == "op"  gen double bgkap = betakappa * kappa1
label var bgkap "betak * gk * kappa"
if "`esttype'" == "op"  gen double bgmu = betamu * mu
label var bgmu "betam * gm * mu"
drop bsecfe50 beta* ols* wi* _merge lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed bgkap bgmu kappa1 mu

* collapse to sector level, not in logs, using size variables (as weights) as in brazprod/%4tfp/prodlevel.do
gen fsize = exp(lnoutput)
label var fsize "Firm Size (Output)"
gen lbftot = labfbl + labfwh
label var lbftot "Total Labor Force"
* mean lntfp and lnlp [weighted by output and employment]
preserve
  tempfile lntfp
  collapse (mean) lntfp [w=fsize], by(niv50 year) fast
  sort niv50 year
  label var lntfp "Log TFP [output weighted]"
  save `lntfp'
restore, preserve
  tempfile lnlp
  collapse (mean) lnlp [w=lbftot], by(niv50 year) fast
  sort niv50 year
  label var lnlp "Log LP [workforce weighted]"
  save `lnlp'
restore


// Put together

* niv100
use `ratio100', clear
gen byte niv50 = int(niv100/100)
label var niv50 "Sector (Nivel 50)"
sort niv50 year
merge niv50 year using `lntfp'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
sort niv50 year
merge niv50 year using `lnlp'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
order niv100 niv50 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl lntfp lnlp
replace year = year + 1900
sort niv100 year 
merge niv100 year using `rais100'
tab _m
replace niv50 = int(niv100/100) if niv50==.
tab niv50 if _m==1 & year<1995  // no information in RAIS at CNAE level before 1995
tab niv50 if _m==1 & year>1994  // complete CNAE information in RAIS after 1994
tab niv50 if _m==2 & year<1999  // no information in PIA on sectors 1, 2, 3, 1530, 32
tab niv50 if _m==2 & year>1998  // no information in PIA after 1998
drop _m
drop lntfp lnlp niv50  // not at nivel 100 level
qui do "rais/cnae/niv100.do"
label values niv100 niv100
sort niv100 year 
compress
save "brazrloc/auxil/niv100-agg", replace

use `ratio50', clear
sort niv50 year
merge niv50 year using `lntfp'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
sort niv50 year
merge niv50 year using `lnlp'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
order niv50 year empl cap valadd_empl sales_empl cap_empl intmed_empl profit_sales labfwh_empl lntfp lnlp
replace year = year + 1900
sort niv50 year 
merge niv50 year using `rais50'
tab _m
tab niv50 if _m==1 & year<1995  // no information in RAIS at CNAE level before 1995
tab niv50 if _m==1 & year>1994  // complete CNAE information in RAIS after 1994
tab niv50 if _m==2 & year<1999  // no information in PIA on sectors 1, 2, 3, 32 (15 includes 1510 and 1520 in PIA)
tab niv50 if _m==2 & year>1998  // no information in PIA after 1998
drop _m
qui do "rais/cnae/niv50.do"
label values niv50 niv50
sort niv50 year 
compress
save "brazrloc/auxil/niv50-agg", replace

log close
cd "$home"
