version 8
set more off
set virtual on
clear
set trace off

cd "$root"

capture mkdir "brazrloc/graphs/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/graphs/v4/metromale-prime/duration"
capture mkdir "brazrloc/tex/v4/metromale-prime/duration"

capture log close
log using "brazrloc/logs/durations-metromale-prime.log", replace

* COUNTS OF LACKING REALLOCATIONS AFTER 48 AND 60 MONHTS

foreach dur in 12 24 36 48 60 {

use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop fx_etaria

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"

* calculate months from displacement to first rehiring, if within 48 or 60 months
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* assign indicator to workers not reemployed within 48 and 60 months
drop if inddspl==0
gen byte indnorloc = (mo2rehir > `dur' | mo2rehir==.)
keep ano mes_desl indnorloc
label var indnorloc "Indic.: No reall. in `dur' months"
collapse (mean) indnorloc, by(ano mes_desl) fast
if `dur'==60  keep if ano<=1996
if `dur'==48  keep if ano<=1997
if `dur'==36  keep if ano<=1998
if `dur'==24  keep if ano<=1999
if `dur'==12  keep if ano<=2000
gen day = mdy(mes_desl,1,ano) 
label var day "Month of displacement"
format day %dm/CY
graph twoway connected indnorloc day, ytitle("") legend( label(1 "Share of non-reallocated") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/metromale-prime/duration/indnorloc`dur'm.eps", replace
graph twoway connected indnorloc day, ytitle("") legend( label(1 "Share of non-reallocated") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/metromale-prime/duration/indnorloc`dur'm-color.eps", replace

collapse (mean) indnorloc, by(ano) fast
gen str7 _rowname = string(ano)
drop ano
order _rowname
sort _rowname
save indnorloc`dur'm_tbl, replace
matload indnorloc`dur'm_tbl, dropall over missing(.)
erase indnorloc`dur'm_tbl.dta
est2tex indnorloc`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/duration) fancy digits(3)

}

* DURATIONS OF SUCCESSFUL REALLOCATIONS WITHIN 36 AND 48 MONTHS

foreach dur in 36 48 {

use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop fx_etaria

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"

* discard rehirings if plant missing in year before rehiring
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-list-metro"
tab _m
keep if _m==3
keep wid ano mes_adm mes_deslig identificad inddspl morehir indabsyr1 caus_desl_tc
sort wid ano mes_adm mes_deslig identificad
by wid: gen inddisc = indabsyr1[_n+1]
label var inddisc "Plant missing year bef. realloc."

* calculate months from displacement to first rehiring, if within 36 or 48 months
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* graph and tabulate months from displacement to first rehiring, if within `dur' months but irrespective of plant absence
preserve
  if `dur'==36  keep if ano<=1998
  if `dur'==48  keep if ano<=1997
  keep ano mes_desl mo2rehir
  collapse (mean) mo2rehir (median) medmo2rehir=mo2rehir, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var mo2rehir "Mean months to re-employment"
  label var medmo2rehir "Median months to re-employment"
  format day %dm/CY
  qui regress mo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict mo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress mo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict mo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress mo2rehir if day > mdy(12,31,1992)
  predict mo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/mo2rehr`dur'm.eps", replace
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/mo2rehr`dur'm-color.eps", replace
  qui regress medmo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict medmo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress medmo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict medmo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress medmo2rehir if day > mdy(12,31,1992)
  predict medmo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected medmo2rehir medmo2rehir_per1 medmo2rehir_per2 medmo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/medmo2rehr`dur'm.eps", replace
  graph twoway connected medmo2rehir medmo2rehir_per1 medmo2rehir_per2 medmo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/medmo2rehr`dur'm-color.eps", replace
  collapse (mean) mo2rehir, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save mo2rehr`dur'm_tbl, replace
  matload mo2rehr`dur'm_tbl, dropall over missing(.)
  erase mo2rehr`dur'm_tbl.dta
  est2tex mo2rehr`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/duration) fancy digits(3)
restore, preserve

* graph and tabulate months from displacement to first rehiring, if within `dur' months and plant does not exhibit absence
  replace mo2rehir = . if mo2rehir>`dur' | inddisc==1
  if `dur'==36  keep if ano>=1987 & ano<=1998
  if `dur'==48  keep if ano>=1987 & ano<=1997
  keep ano mes_desl mo2rehir
  collapse (mean) mo2rehir (median) medmo2rehir=mo2rehir, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var mo2rehir "Mean months to re-employment"
  label var medmo2rehir "Median months to re-employment"
  format day %dm/CY
  qui regress mo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict mo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress mo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict mo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress mo2rehir if day > mdy(12,31,1992)
  predict mo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/mo2rehr`dur'm-contplants.eps", replace
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/mo2rehr`dur'm-contplants-color.eps", replace
  collapse (mean) mo2rehir, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save mo2rehr`dur'm_cntplnts_tbl, replace
  matload mo2rehr`dur'm_cntplnts_tbl, dropall over missing(.)
  erase mo2rehr`dur'm_cntplnts_tbl.dta
  est2tex mo2rehr`dur'm_cntplnts, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/duration) fancy digits(3)
restore  

* calculate half life of worker pool to be reallocated
sort ano mes_deslig mo2rehir wid mes_adm identificad
by ano mes_deslig: gen _halfreloc = mo2rehir if _n==int(_N/2)
egen halflife = max(_halfreloc), by(ano mes_deslig)
drop _halfreloc
label var halflife "Half life of realloc. pool"
sort wid ano mes_adm mes_deslig identificad

* graph and tabulate half life of displaced cohorts, if reallocation within `dur' months but irrespective of plant absence
preserve
  if `dur'==36  keep if ano<=1998
  if `dur'==48  keep if ano<=1997
  keep ano mes_desl halflife
  collapse (mean) halflife, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var halflife "Half life of reallocation pool"
  format day %dm/CY
  qui regress halflife day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict halflife_per1 if day <= mdy(12,31,1989), xb
  qui regress halflife day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict halflife_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress halflife if day > mdy(12,31,1992)
  predict halflife_per3 if day > mdy(12,31,1992), xb
  graph twoway connected halflife halflife_per1 halflife_per2 halflife_per3 day, ytitle("") legend( label(1 "Half life in months") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/halflife`dur'm.eps", replace
  graph twoway connected halflife halflife_per1 halflife_per2 halflife_per3 day, ytitle("") legend( label(1 "Half life in months") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/metromale-prime/duration/halflife`dur'm-color.eps", replace
  collapse (mean) halflife, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save halflife`dur'm_tbl, replace
  matload halflife`dur'm_tbl, dropall over missing(.)
  erase halflife`dur'm_tbl.dta
  est2tex halflife`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/duration) fancy digits(3)
restore

}

log close
cd "$root"
