version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"

capture log close
log using "brazrloc/logs/separations-accessions-aspme.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local focallst "subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "subs_balcadv_indexp subs_balcadv_indexp_tarf"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* separations natl

use if ~indexcl using "brazrloc/data/separations-natl-maleprime-subsibge.dta", clear

clogit inddspl subs_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(natldspl_tarfoutp)

clogit inddspl subs_tarfoutp subs_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(natldspl_tarfboth)

* separations metro

use if ~indexcl using "brazrloc/data/separations-metromale-prime-subsibge.dta", clear

clogit inddspl subs_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(metrodspl_tarfoutp)

clogit inddspl subs_tarfoutp subs_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(metrodspl_tarfboth)

* accessions natl

use if ~indexcl using "brazrloc/data/accessions-natl-maleprime-subsibge.dta", clear

clogit indhire subs_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(natlhire_tarfoutp)

clogit indhire subs_tarfoutp subs_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(natlhire_tarfboth)

* accessions metro

use if ~indexcl using "brazrloc/data/accessions-metromale-prime-subsibge.dta", clear

clogit indhire subs_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(metrohire_tarfoutp)

clogit indhire subs_tarfoutp subs_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_subs_aspme, addto(dsplhire_subs_aspme) name(metrohire_tarfboth)


// CNAE REGRESSIONS 

local focallst "cnae_balcadv cnae_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "cnae_balcadv_indexp cnae_balcadv_indexp_tarf"
local cntrlfrm "cnae_secrealx cnae_fdiflw cnae_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "cnae_tarfoutp cnae_tarfintm cnae_reffpen"
local baseiv   "cnae_dollar cnae_ppieu cnae_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* separations natl

use if ~indexcl using "brazrloc/data/separations-natl-maleprime-cnae.dta", clear

clogit inddspl cnae_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, vars(cnae_balcadv cnae_balcadv_tarf firm_indexp firm_indexp_tarf cnae_balcadv_indexp cnae_balcadv_indexp_tarf cnae_tarfoutp cnae_tarfintm cnae_reffpen prd_cnae_tarfoutp res_cnae_tarfoutp prd_cnae_tarfintm res_cnae_tarfintm prd_cnae_reffpen res_cnae_reffpen prd_indexp res_indexp cnae_fdiflw cnae_herfsale cnae_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 cnae_dollar cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(natldspl_tarfoutp)

clogit inddspl cnae_tarfoutp cnae_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(natldspl_tarfboth)

* separations metro

use if ~indexcl using "brazrloc/data/separations-metromale-prime-cnae.dta", clear

clogit inddspl cnae_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(metrodspl_tarfoutp)

clogit inddspl cnae_tarfoutp cnae_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(metrodspl_tarfboth)

* accessions natl

use if ~indexcl using "brazrloc/data/accessions-natl-maleprime-cnae.dta", clear

clogit indhire cnae_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(natlhire_tarfoutp)

clogit indhire cnae_tarfoutp cnae_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(natlhire_tarfboth)

* accessions metro

use if ~indexcl using "brazrloc/data/accessions-metromale-prime-cnae.dta", clear

clogit indhire cnae_tarfoutp `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(metrohire_tarfoutp)

clogit indhire cnae_tarfoutp cnae_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec dsplhire_cnae_aspme, addto(dsplhire_cnae_aspme) name(metrohire_tarfboth)


// SAVE RESULTS

foreach type in b se e {
  matsave dsplhire_subs_aspme_`type', p(brazrloc/estmat/v4/reg) t(double) replace dropall
  matsave dsplhire_cnae_aspme_`type', p(brazrloc/estmat/v4/reg) t(double) replace dropall
  }

log close
